# expand_abbreviations

Performs the following expansions on anything with [word boundaries on both sides](https://www.regular-expressions.info/wordboundaries.html):

* 'co' to 'company'
* 'ltd' to 'limited'
